from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI
import win32more.Microsoft.Windows.Media.Capture
import win32more.Windows.Foundation
import win32more.Windows.Storage
class CameraCaptureUI(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUI
    _classid_ = 'Microsoft.Windows.Media.Capture.CameraCaptureUI'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.Media.Capture.CameraCaptureUI.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIFactory, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUI: ...
    @winrt_mixinmethod
    def get_PhotoSettings(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUI) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoCaptureSettings: ...
    @winrt_mixinmethod
    def get_VideoSettings(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUI) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoCaptureSettings: ...
    @winrt_mixinmethod
    def CaptureFileAsync(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUI, mode: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    PhotoSettings = property(get_PhotoSettings, None)
    VideoSettings = property(get_VideoSettings, None)
CameraCaptureUIContract: UInt32 = 65536
class CameraCaptureUIMaxPhotoResolution(Enum, Int32):
    HighestAvailable = 0
    VerySmallQvga = 1
    SmallVga = 2
    MediumXga = 3
    Large3M = 4
    VeryLarge5M = 5
class CameraCaptureUIMaxVideoResolution(Enum, Int32):
    HighestAvailable = 0
    LowDefinition = 1
    StandardDefinition = 2
    HighDefinition = 3
class CameraCaptureUIMode(Enum, Int32):
    PhotoOrVideo = 0
    Photo = 1
    Video = 2
class CameraCaptureUIPhotoCaptureSettings(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings
    _classid_ = 'Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoCaptureSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoCaptureSettings.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoCaptureSettings: ...
    @winrt_mixinmethod
    def get_AllowCropping(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowCropping(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_CroppedAspectRatio(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def put_CroppedAspectRatio(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings, value: win32more.Windows.Foundation.Size) -> Void: ...
    @winrt_mixinmethod
    def get_CroppedSizeInPixels(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings) -> win32more.Windows.Foundation.Size: ...
    @winrt_mixinmethod
    def put_CroppedSizeInPixels(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings, value: win32more.Windows.Foundation.Size) -> Void: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoFormat: ...
    @winrt_mixinmethod
    def put_Format(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoFormat) -> Void: ...
    @winrt_mixinmethod
    def get_MaxResolution(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxPhotoResolution: ...
    @winrt_mixinmethod
    def put_MaxResolution(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxPhotoResolution) -> Void: ...
    AllowCropping = property(get_AllowCropping, put_AllowCropping)
    CroppedAspectRatio = property(get_CroppedAspectRatio, put_CroppedAspectRatio)
    CroppedSizeInPixels = property(get_CroppedSizeInPixels, put_CroppedSizeInPixels)
    Format = property(get_Format, put_Format)
    MaxResolution = property(get_MaxResolution, put_MaxResolution)
class CameraCaptureUIPhotoFormat(Enum, Int32):
    Jpeg = 0
    Png = 1
    JpegXR = 2
class CameraCaptureUIVideoCaptureSettings(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings
    _classid_ = 'Microsoft.Windows.Media.Capture.CameraCaptureUIVideoCaptureSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoCaptureSettings.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoCaptureSettings: ...
    @winrt_mixinmethod
    def get_AllowTrimming(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_AllowTrimming(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoFormat: ...
    @winrt_mixinmethod
    def put_Format(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoFormat) -> Void: ...
    @winrt_mixinmethod
    def get_MaxDurationInSeconds(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings) -> Single: ...
    @winrt_mixinmethod
    def put_MaxDurationInSeconds(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_MaxResolution(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxVideoResolution: ...
    @winrt_mixinmethod
    def put_MaxResolution(self: win32more.Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxVideoResolution) -> Void: ...
    AllowTrimming = property(get_AllowTrimming, put_AllowTrimming)
    Format = property(get_Format, put_Format)
    MaxDurationInSeconds = property(get_MaxDurationInSeconds, put_MaxDurationInSeconds)
    MaxResolution = property(get_MaxResolution, put_MaxResolution)
class CameraCaptureUIVideoFormat(Enum, Int32):
    Mp4 = 0
    Wmv = 1
class ICameraCaptureUI(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Media.Capture.ICameraCaptureUI'
    _iid_ = Guid('{c001d024-c617-5742-9ae1-8fd31be07f6c}')
    @winrt_commethod(6)
    def get_PhotoSettings(self) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoCaptureSettings: ...
    @winrt_commethod(7)
    def get_VideoSettings(self) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoCaptureSettings: ...
    @winrt_commethod(8)
    def CaptureFileAsync(self, mode: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    PhotoSettings = property(get_PhotoSettings, None)
    VideoSettings = property(get_VideoSettings, None)
class ICameraCaptureUIFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Media.Capture.ICameraCaptureUIFactory'
    _iid_ = Guid('{2b49623d-5f22-5fee-991f-14f24592a3c2}')
    @winrt_commethod(6)
    def CreateInstance(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUI: ...
class ICameraCaptureUIPhotoCaptureSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Media.Capture.ICameraCaptureUIPhotoCaptureSettings'
    _iid_ = Guid('{19fe2155-d018-53fc-bbdc-5781a94687a0}')
    @winrt_commethod(6)
    def get_AllowCropping(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AllowCropping(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_CroppedAspectRatio(self) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(9)
    def put_CroppedAspectRatio(self, value: win32more.Windows.Foundation.Size) -> Void: ...
    @winrt_commethod(10)
    def get_CroppedSizeInPixels(self) -> win32more.Windows.Foundation.Size: ...
    @winrt_commethod(11)
    def put_CroppedSizeInPixels(self, value: win32more.Windows.Foundation.Size) -> Void: ...
    @winrt_commethod(12)
    def get_Format(self) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoFormat: ...
    @winrt_commethod(13)
    def put_Format(self, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIPhotoFormat) -> Void: ...
    @winrt_commethod(14)
    def get_MaxResolution(self) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxPhotoResolution: ...
    @winrt_commethod(15)
    def put_MaxResolution(self, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxPhotoResolution) -> Void: ...
    AllowCropping = property(get_AllowCropping, put_AllowCropping)
    CroppedAspectRatio = property(get_CroppedAspectRatio, put_CroppedAspectRatio)
    CroppedSizeInPixels = property(get_CroppedSizeInPixels, put_CroppedSizeInPixels)
    Format = property(get_Format, put_Format)
    MaxResolution = property(get_MaxResolution, put_MaxResolution)
class ICameraCaptureUIVideoCaptureSettings(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Media.Capture.ICameraCaptureUIVideoCaptureSettings'
    _iid_ = Guid('{47dd74f6-83b7-5123-bbdf-d757201d1ee8}')
    @winrt_commethod(6)
    def get_AllowTrimming(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_AllowTrimming(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_Format(self) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoFormat: ...
    @winrt_commethod(9)
    def put_Format(self, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIVideoFormat) -> Void: ...
    @winrt_commethod(10)
    def get_MaxDurationInSeconds(self) -> Single: ...
    @winrt_commethod(11)
    def put_MaxDurationInSeconds(self, value: Single) -> Void: ...
    @winrt_commethod(12)
    def get_MaxResolution(self) -> win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxVideoResolution: ...
    @winrt_commethod(13)
    def put_MaxResolution(self, value: win32more.Microsoft.Windows.Media.Capture.CameraCaptureUIMaxVideoResolution) -> Void: ...
    AllowTrimming = property(get_AllowTrimming, put_AllowTrimming)
    Format = property(get_Format, put_Format)
    MaxDurationInSeconds = property(get_MaxDurationInSeconds, put_MaxDurationInSeconds)
    MaxResolution = property(get_MaxResolution, put_MaxResolution)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.Widgets.Notifications
import win32more.Windows.Foundation
class AnnouncementActionKind(Enum, Int32):
    Shown = 0
    Engaged = 1
class AnnouncementTextColor(Enum, Int32):
    Default = 0
    Dark = 1
    Light = 2
    Accent = 3
    Good = 4
    Warning = 5
    Attention = 6
class FeedAnnouncement(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.FeedAnnouncement'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 5:
            super().__init__(move=win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementFactory, id: WinRT_String, primaryText: WinRT_String, secondaryText: WinRT_String, lightModeIcon: win32more.Windows.Foundation.Uri, darkModeIcon: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Id(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PrimaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_SecondaryText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_LightModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_LightModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_DarkModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_DarkModeIconUri(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_PrimaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_mixinmethod
    def put_PrimaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_mixinmethod
    def get_SecondaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_mixinmethod
    def put_SecondaryTextColor(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_mixinmethod
    def get_CustomAccessibilityText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CustomAccessibilityText(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsSecondaryTextSubtle(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSecondaryTextSubtle(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ShowBadgeIfUserNotEngaged(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> Boolean: ...
    @winrt_mixinmethod
    def put_ShowBadgeIfUserNotEngaged(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ExpirationTime(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_ExpirationTime(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def put_Duration(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    CustomAccessibilityText = property(get_CustomAccessibilityText, put_CustomAccessibilityText)
    DarkModeIconUri = property(get_DarkModeIconUri, put_DarkModeIconUri)
    Duration = property(get_Duration, put_Duration)
    ExpirationTime = property(get_ExpirationTime, put_ExpirationTime)
    Id = property(get_Id, put_Id)
    IsSecondaryTextSubtle = property(get_IsSecondaryTextSubtle, put_IsSecondaryTextSubtle)
    LightModeIconUri = property(get_LightModeIconUri, put_LightModeIconUri)
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    PrimaryTextColor = property(get_PrimaryTextColor, put_PrimaryTextColor)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    SecondaryTextColor = property(get_SecondaryTextColor, put_SecondaryTextColor)
    ShowBadgeIfUserNotEngaged = property(get_ShowBadgeIfUserNotEngaged, put_ShowBadgeIfUserNotEngaged)
class FeedAnnouncementInvokedArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.FeedAnnouncementInvokedArgs'
    @winrt_mixinmethod
    def get_FeedProviderDefinitionId(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FeedDefinitionId(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AnnouncementId(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ActionKind(self: win32more.Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementActionKind: ...
    ActionKind = property(get_ActionKind, None)
    AnnouncementId = property(get_AnnouncementId, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)
class IFeedAnnouncement(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.IFeedAnnouncement'
    _iid_ = Guid('{b88e8c2c-d251-5344-acc2-8cf9ba07ec15}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Id(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_PrimaryText(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_PrimaryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_SecondaryText(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_SecondaryText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_LightModeIconUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(13)
    def put_LightModeIconUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(14)
    def get_DarkModeIconUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(15)
    def put_DarkModeIconUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(16)
    def get_PrimaryTextColor(self) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_commethod(17)
    def put_PrimaryTextColor(self, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_commethod(18)
    def get_SecondaryTextColor(self) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor: ...
    @winrt_commethod(19)
    def put_SecondaryTextColor(self, value: win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementTextColor) -> Void: ...
    @winrt_commethod(20)
    def get_CustomAccessibilityText(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_CustomAccessibilityText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_IsSecondaryTextSubtle(self) -> Boolean: ...
    @winrt_commethod(23)
    def put_IsSecondaryTextSubtle(self, value: Boolean) -> Void: ...
    @winrt_commethod(24)
    def get_ShowBadgeIfUserNotEngaged(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_ShowBadgeIfUserNotEngaged(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_ExpirationTime(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(27)
    def put_ExpirationTime(self, value: win32more.Windows.Foundation.DateTime) -> Void: ...
    @winrt_commethod(28)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(29)
    def put_Duration(self, value: win32more.Windows.Foundation.TimeSpan) -> Void: ...
    CustomAccessibilityText = property(get_CustomAccessibilityText, put_CustomAccessibilityText)
    DarkModeIconUri = property(get_DarkModeIconUri, put_DarkModeIconUri)
    Duration = property(get_Duration, put_Duration)
    ExpirationTime = property(get_ExpirationTime, put_ExpirationTime)
    Id = property(get_Id, put_Id)
    IsSecondaryTextSubtle = property(get_IsSecondaryTextSubtle, put_IsSecondaryTextSubtle)
    LightModeIconUri = property(get_LightModeIconUri, put_LightModeIconUri)
    PrimaryText = property(get_PrimaryText, put_PrimaryText)
    PrimaryTextColor = property(get_PrimaryTextColor, put_PrimaryTextColor)
    SecondaryText = property(get_SecondaryText, put_SecondaryText)
    SecondaryTextColor = property(get_SecondaryTextColor, put_SecondaryTextColor)
    ShowBadgeIfUserNotEngaged = property(get_ShowBadgeIfUserNotEngaged, put_ShowBadgeIfUserNotEngaged)
class IFeedAnnouncementFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementFactory'
    _iid_ = Guid('{22074243-46d8-5af2-8715-1c76d1cb774c}')
    @winrt_commethod(6)
    def CreateInstance(self, id: WinRT_String, primaryText: WinRT_String, secondaryText: WinRT_String, lightModeIcon: win32more.Windows.Foundation.Uri, darkModeIcon: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Windows.Widgets.Notifications.FeedAnnouncement: ...
class IFeedAnnouncementInvokedArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Widgets.Notifications.IFeedAnnouncementInvokedArgs'
    _iid_ = Guid('{70a48d98-323d-5f19-a1e1-b63fe36edbf2}')
    @winrt_commethod(6)
    def get_FeedProviderDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FeedDefinitionId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AnnouncementId(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_ActionKind(self) -> win32more.Microsoft.Windows.Widgets.Notifications.AnnouncementActionKind: ...
    ActionKind = property(get_ActionKind, None)
    AnnouncementId = property(get_AnnouncementId, None)
    FeedDefinitionId = property(get_FeedDefinitionId, None)
    FeedProviderDefinitionId = property(get_FeedProviderDefinitionId, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.Security.AccessControl
AccessControlContract: UInt32 = 65536
class AppContainerNameAndAccess(Structure):
    appContainerName: WinRT_String
    accessMask: UInt32
class ISecurityDescriptorHelpersStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Security.AccessControl.ISecurityDescriptorHelpersStatics'
    _iid_ = Guid('{14fa9e8d-59f0-5017-852f-3ae24fd5ebb1}')
    @winrt_commethod(6)
    def GetSddlForAppContainerNames(self, accessRequests: PassArray[win32more.Microsoft.Windows.Security.AccessControl.AppContainerNameAndAccess], principalStringSid: WinRT_String, principalAccessMask: UInt32) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetSecurityDescriptorBytesFromAppContainerNames(self, accessRequests: PassArray[win32more.Microsoft.Windows.Security.AccessControl.AppContainerNameAndAccess], principalStringSid: WinRT_String, principalAccessMask: UInt32) -> ReceiveArray[Byte]: ...
class SecurityDescriptorHelpers(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.Security.AccessControl.SecurityDescriptorHelpers'
    @winrt_classmethod
    def GetSddlForAppContainerNames(cls: win32more.Microsoft.Windows.Security.AccessControl.ISecurityDescriptorHelpersStatics, accessRequests: PassArray[win32more.Microsoft.Windows.Security.AccessControl.AppContainerNameAndAccess], principalStringSid: WinRT_String, principalAccessMask: UInt32) -> WinRT_String: ...
    @winrt_classmethod
    def GetSecurityDescriptorBytesFromAppContainerNames(cls: win32more.Microsoft.Windows.Security.AccessControl.ISecurityDescriptorHelpersStatics, accessRequests: PassArray[win32more.Microsoft.Windows.Security.AccessControl.AppContainerNameAndAccess], principalStringSid: WinRT_String, principalAccessMask: UInt32) -> ReceiveArray[Byte]: ...


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.ApplicationModel.Background
import win32more.Windows.ApplicationModel.Background
class BackgroundTaskBuilder(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder
    _classid_ = 'Microsoft.Windows.ApplicationModel.Background.BackgroundTaskBuilder'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.Background.BackgroundTaskBuilder.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.Background.BackgroundTaskBuilder: ...
    @winrt_mixinmethod
    def SetTrigger(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder, trigger: win32more.Windows.ApplicationModel.Background.IBackgroundTrigger) -> Void: ...
    @winrt_mixinmethod
    def SetTaskEntryPointClsid(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder, clsId: Guid) -> Void: ...
    @winrt_mixinmethod
    def AddCondition(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder, condition: win32more.Windows.ApplicationModel.Background.IBackgroundCondition) -> Void: ...
    @winrt_mixinmethod
    def put_Name(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_TaskGroup(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder, value: win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistrationGroup) -> Void: ...
    @winrt_mixinmethod
    def get_TaskGroup(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistrationGroup: ...
    @winrt_mixinmethod
    def Register(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistration: ...
    @winrt_mixinmethod
    def Register2(self: win32more.Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder, name: WinRT_String) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistration: ...
    Name = property(get_Name, put_Name)
    TaskGroup = property(get_TaskGroup, put_TaskGroup)
BackgroundTaskContract: UInt32 = 65536
class IBackgroundTaskBuilder(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.Background.IBackgroundTaskBuilder'
    _iid_ = Guid('{32a355a0-75ca-5cb8-9f8e-2c4ea62d1ee3}')
    @winrt_commethod(6)
    def SetTrigger(self, trigger: win32more.Windows.ApplicationModel.Background.IBackgroundTrigger) -> Void: ...
    @winrt_commethod(7)
    def SetTaskEntryPointClsid(self, clsId: Guid) -> Void: ...
    @winrt_commethod(8)
    def AddCondition(self, condition: win32more.Windows.ApplicationModel.Background.IBackgroundCondition) -> Void: ...
    @winrt_commethod(9)
    def put_Name(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_TaskGroup(self, value: win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistrationGroup) -> Void: ...
    @winrt_commethod(12)
    def get_TaskGroup(self) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistrationGroup: ...
    @winrt_commethod(13)
    def Register(self) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistration: ...
    @winrt_commethod(14)
    def Register2(self, name: WinRT_String) -> win32more.Windows.ApplicationModel.Background.BackgroundTaskRegistration: ...
    Name = property(get_Name, put_Name)
    TaskGroup = property(get_TaskGroup, put_TaskGroup)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.ApplicationModel.DynamicDependency
import win32more.Windows.ApplicationModel
class AddPackageDependencyOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions: ...
    @winrt_mixinmethod
    def get_Rank(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_Rank(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_PrependIfRankCollision(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_PrependIfRankCollision(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions, value: Boolean) -> Void: ...
    PrependIfRankCollision = property(get_PrependIfRankCollision, put_PrependIfRankCollision)
    Rank = property(get_Rank, put_Rank)
class CreatePackageDependencyOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions: ...
    @winrt_mixinmethod
    def get_Architectures(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures: ...
    @winrt_mixinmethod
    def put_Architectures(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures) -> Void: ...
    @winrt_mixinmethod
    def get_VerifyDependencyResolution(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_VerifyDependencyResolution(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_LifetimeArtifactKind(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind: ...
    @winrt_mixinmethod
    def put_LifetimeArtifactKind(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind) -> Void: ...
    @winrt_mixinmethod
    def get_LifetimeArtifact(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_LifetimeArtifact(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions, value: WinRT_String) -> Void: ...
    Architectures = property(get_Architectures, put_Architectures)
    LifetimeArtifact = property(get_LifetimeArtifact, put_LifetimeArtifact)
    LifetimeArtifactKind = property(get_LifetimeArtifactKind, put_LifetimeArtifactKind)
    VerifyDependencyResolution = property(get_VerifyDependencyResolution, put_VerifyDependencyResolution)
DynamicDependencyContract: UInt32 = 131072
class IAddPackageDependencyOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IAddPackageDependencyOptions'
    _iid_ = Guid('{01b801fd-24e3-5e6b-9f1c-805ab410b604}')
    @winrt_commethod(6)
    def get_Rank(self) -> Int32: ...
    @winrt_commethod(7)
    def put_Rank(self, value: Int32) -> Void: ...
    @winrt_commethod(8)
    def get_PrependIfRankCollision(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_PrependIfRankCollision(self, value: Boolean) -> Void: ...
    PrependIfRankCollision = property(get_PrependIfRankCollision, put_PrependIfRankCollision)
    Rank = property(get_Rank, put_Rank)
class ICreatePackageDependencyOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.ICreatePackageDependencyOptions'
    _iid_ = Guid('{cdbb820f-3c69-55dc-a017-b4132574c5d6}')
    @winrt_commethod(6)
    def get_Architectures(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures: ...
    @winrt_commethod(7)
    def put_Architectures(self, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyProcessorArchitectures) -> Void: ...
    @winrt_commethod(8)
    def get_VerifyDependencyResolution(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_VerifyDependencyResolution(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_LifetimeArtifactKind(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind: ...
    @winrt_commethod(11)
    def put_LifetimeArtifactKind(self, value: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyLifetimeArtifactKind) -> Void: ...
    @winrt_commethod(12)
    def get_LifetimeArtifact(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_LifetimeArtifact(self, value: WinRT_String) -> Void: ...
    Architectures = property(get_Architectures, put_Architectures)
    LifetimeArtifact = property(get_LifetimeArtifact, put_LifetimeArtifact)
    LifetimeArtifactKind = property(get_LifetimeArtifactKind, put_LifetimeArtifactKind)
    VerifyDependencyResolution = property(get_VerifyDependencyResolution, put_VerifyDependencyResolution)
class IPackageDependency(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency'
    _iid_ = Guid('{32ae7b95-e358-5a48-9669-c97d85ad6556}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def Delete(self) -> Void: ...
    @winrt_commethod(8)
    def Add(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_commethod(9)
    def Add2(self, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    Id = property(get_Id, None)
class IPackageDependencyContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext'
    _iid_ = Guid('{9902c35a-a3f5-5645-af0f-cdf9fca00d5e}')
    @winrt_commethod(6)
    def get_ContextId(self) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId: ...
    @winrt_commethod(7)
    def get_PackageDependencyId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_PackageFullName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def Remove(self) -> Void: ...
    ContextId = property(get_ContextId, None)
    PackageDependencyId = property(get_PackageDependencyId, None)
    PackageFullName = property(get_PackageFullName, None)
class IPackageDependencyContextFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContextFactory'
    _iid_ = Guid('{9914f24f-bebf-516b-adab-5c3e8bf323f8}')
    @winrt_commethod(6)
    def CreateInstance(self, contextId: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
class IPackageDependencyRankStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyRankStatics'
    _iid_ = Guid('{260583bd-a4ab-53fd-a190-c446bfdb5384}')
    @winrt_commethod(6)
    def get_Default(self) -> Int32: ...
    Default = property(get_Default, None)
class IPackageDependencyStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics'
    _iid_ = Guid('{17b656e1-1a58-5f3c-84a8-4430f6e749c2}')
    @winrt_commethod(6)
    def GetFromId(self, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(7)
    def GetFromIdForSystem(self, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(8)
    def Create(self, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(9)
    def Create2(self, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(10)
    def CreateForSystem(self, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_commethod(11)
    def get_GenerationId(self) -> UInt32: ...
    GenerationId = property(get_GenerationId, None)
class IPackageDependencyStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics2'
    _iid_ = Guid('{c7c6e4f3-c0ca-5fdb-bef2-57e6020ffe4e}')
    @winrt_commethod(6)
    def get_PackageGraphRevisionId(self) -> UInt32: ...
    PackageGraphRevisionId = property(get_PackageGraphRevisionId, None)
class _PackageDependency_Meta_(ComPtr.__class__):
    pass
class PackageDependency(ComPtr, metaclass=_PackageDependency_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency'
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency) -> WinRT_String: ...
    @winrt_mixinmethod
    def Delete(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency) -> Void: ...
    @winrt_mixinmethod
    def Add(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_mixinmethod
    def Add2(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependency, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.AddPackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_classmethod
    def get_PackageGraphRevisionId(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics2) -> UInt32: ...
    @winrt_classmethod
    def GetFromId(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def GetFromIdForSystem(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, id: WinRT_String) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def Create2(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def CreateForSystem(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics, packageFamilyName: WinRT_String, minVersion: win32more.Windows.ApplicationModel.PackageVersion, options: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.CreatePackageDependencyOptions) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependency: ...
    @winrt_classmethod
    def get_GenerationId(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyStatics) -> UInt32: ...
    Id = property(get_Id, None)
    _PackageDependency_Meta_.GenerationId = property(get_GenerationId, None)
    _PackageDependency_Meta_.PackageGraphRevisionId = property(get_PackageGraphRevisionId, None)
class PackageDependencyContext(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContextFactory, contextId: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContext: ...
    @winrt_mixinmethod
    def get_ContextId(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyContextId: ...
    @winrt_mixinmethod
    def get_PackageDependencyId(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_PackageFullName(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> WinRT_String: ...
    @winrt_mixinmethod
    def Remove(self: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyContext) -> Void: ...
    ContextId = property(get_ContextId, None)
    PackageDependencyId = property(get_PackageDependencyId, None)
    PackageFullName = property(get_PackageFullName, None)
class PackageDependencyContextId(Structure):
    Id: UInt64
class PackageDependencyLifetimeArtifactKind(Enum, Int32):
    Process = 0
    FilePath = 1
    RegistryKey = 2
class PackageDependencyProcessorArchitectures(Enum, UInt32):
    None_ = 0
    Neutral = 1
    X86 = 2
    X64 = 4
    Arm = 8
    Arm64 = 16
    X86OnArm64 = 32
class _PackageDependencyRank_Meta_(ComPtr.__class__):
    pass
class PackageDependencyRank(ComPtr, metaclass=_PackageDependencyRank_Meta_):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.ApplicationModel.DynamicDependency.PackageDependencyRank'
    @winrt_classmethod
    def get_Default(cls: win32more.Microsoft.Windows.ApplicationModel.DynamicDependency.IPackageDependencyRankStatics) -> Int32: ...
    _PackageDependencyRank_Meta_.Default = property(get_Default, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.AI.ContentSafety
class ContentFilterOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.ContentFilterOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions: ...
    @winrt_mixinmethod
    def get_PromptMaxAllowedSeverityLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
    @winrt_mixinmethod
    def put_PromptMaxAllowedSeverityLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions, value: win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity) -> Void: ...
    @winrt_mixinmethod
    def get_ResponseMaxAllowedSeverityLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
    @winrt_mixinmethod
    def put_ResponseMaxAllowedSeverityLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions, value: win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity) -> Void: ...
    @winrt_mixinmethod
    def get_ImageMaxAllowedSeverityLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions) -> win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity: ...
    @winrt_mixinmethod
    def put_ImageMaxAllowedSeverityLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IContentFilterOptions, value: win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity) -> Void: ...
    ImageMaxAllowedSeverityLevel = property(get_ImageMaxAllowedSeverityLevel, put_ImageMaxAllowedSeverityLevel)
    PromptMaxAllowedSeverityLevel = property(get_PromptMaxAllowedSeverityLevel, put_PromptMaxAllowedSeverityLevel)
    ResponseMaxAllowedSeverityLevel = property(get_ResponseMaxAllowedSeverityLevel, put_ResponseMaxAllowedSeverityLevel)
ContentSafetyContract: UInt32 = 65536
class IContentFilterOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.IContentFilterOptions'
    _iid_ = Guid('{6808be9f-80d2-5136-8a8a-1f5c52c824ad}')
    @winrt_commethod(6)
    def get_PromptMaxAllowedSeverityLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
    @winrt_commethod(7)
    def put_PromptMaxAllowedSeverityLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity) -> Void: ...
    @winrt_commethod(8)
    def get_ResponseMaxAllowedSeverityLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
    @winrt_commethod(9)
    def put_ResponseMaxAllowedSeverityLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity) -> Void: ...
    @winrt_commethod(10)
    def get_ImageMaxAllowedSeverityLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity: ...
    @winrt_commethod(11)
    def put_ImageMaxAllowedSeverityLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity) -> Void: ...
    ImageMaxAllowedSeverityLevel = property(get_ImageMaxAllowedSeverityLevel, put_ImageMaxAllowedSeverityLevel)
    PromptMaxAllowedSeverityLevel = property(get_PromptMaxAllowedSeverityLevel, put_PromptMaxAllowedSeverityLevel)
    ResponseMaxAllowedSeverityLevel = property(get_ResponseMaxAllowedSeverityLevel, put_ResponseMaxAllowedSeverityLevel)
class IImageContentFilterSeverity(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity'
    _iid_ = Guid('{f1563582-c66a-5861-9995-1440b05191ac}')
    @winrt_commethod(6)
    def get_AdultContentLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(7)
    def put_AdultContentLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_commethod(8)
    def get_RacyContentLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(9)
    def put_RacyContentLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_commethod(10)
    def get_GoryContentLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(11)
    def put_GoryContentLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_commethod(12)
    def get_ViolentContentLevel(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(13)
    def put_ViolentContentLevel(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    AdultContentLevel = property(get_AdultContentLevel, put_AdultContentLevel)
    GoryContentLevel = property(get_GoryContentLevel, put_GoryContentLevel)
    RacyContentLevel = property(get_RacyContentLevel, put_RacyContentLevel)
    ViolentContentLevel = property(get_ViolentContentLevel, put_ViolentContentLevel)
class IImageContentFilterSeverityFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverityFactory'
    _iid_ = Guid('{ead11457-81b1-5b81-9ca3-c5b04b4df043}')
    @winrt_commethod(6)
    def CreateInstance(self, severityForALlCategories: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity: ...
class ITextContentFilterSeverity(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity'
    _iid_ = Guid('{68c1ee47-c35c-5f4c-a647-b0c0f64aa0d5}')
    @winrt_commethod(6)
    def get_Hate(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(7)
    def put_Hate(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_commethod(8)
    def get_Sexual(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(9)
    def put_Sexual(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_commethod(10)
    def get_Violent(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(11)
    def put_Violent(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_commethod(12)
    def get_SelfHarm(self) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_commethod(13)
    def put_SelfHarm(self, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    Hate = property(get_Hate, put_Hate)
    SelfHarm = property(get_SelfHarm, put_SelfHarm)
    Sexual = property(get_Sexual, put_Sexual)
    Violent = property(get_Violent, put_Violent)
class ITextContentFilterSeverityFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverityFactory'
    _iid_ = Guid('{e0ca501e-4004-501e-8984-442d091607d4}')
    @winrt_commethod(6)
    def CreateInstance(self, severityForAllCategories: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
class ImageContentFilterSeverity(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverityFactory, severityForALlCategories: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> win32more.Microsoft.Windows.AI.ContentSafety.ImageContentFilterSeverity: ...
    @winrt_mixinmethod
    def get_AdultContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_AdultContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_mixinmethod
    def get_RacyContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_RacyContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_mixinmethod
    def get_GoryContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_GoryContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_mixinmethod
    def get_ViolentContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_ViolentContentLevel(self: win32more.Microsoft.Windows.AI.ContentSafety.IImageContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    AdultContentLevel = property(get_AdultContentLevel, put_AdultContentLevel)
    GoryContentLevel = property(get_GoryContentLevel, put_GoryContentLevel)
    RacyContentLevel = property(get_RacyContentLevel, put_RacyContentLevel)
    ViolentContentLevel = property(get_ViolentContentLevel, put_ViolentContentLevel)
class SeverityLevel(Enum, Int32):
    Minimum = 10
    Low = 11
    Medium = 12
    High = 13
class TextContentFilterSeverity(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity
    _classid_ = 'Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverityFactory, severityForAllCategories: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> win32more.Microsoft.Windows.AI.ContentSafety.TextContentFilterSeverity: ...
    @winrt_mixinmethod
    def get_Hate(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_Hate(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_mixinmethod
    def get_Sexual(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_Sexual(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_mixinmethod
    def get_Violent(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_Violent(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    @winrt_mixinmethod
    def get_SelfHarm(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity) -> win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel: ...
    @winrt_mixinmethod
    def put_SelfHarm(self: win32more.Microsoft.Windows.AI.ContentSafety.ITextContentFilterSeverity, value: win32more.Microsoft.Windows.AI.ContentSafety.SeverityLevel) -> Void: ...
    Hate = property(get_Hate, put_Hate)
    SelfHarm = property(get_SelfHarm, put_SelfHarm)
    Sexual = property(get_Sexual, put_Sexual)
    Violent = property(get_Violent, put_Violent)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Security.Authentication.OAuth
import win32more.Microsoft.UI
import win32more.Windows.Data.Json
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Web.Http
import win32more.Windows.Web.Http.Headers
class AuthFailure(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.IAuthFailure
    _classid_ = 'Microsoft.Security.Authentication.OAuth.AuthFailure'
    @winrt_mixinmethod
    def get_Error(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthFailure) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ErrorDescription(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthFailure) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ErrorUri(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthFailure) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthFailure) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AdditionalParams(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthFailure) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    AdditionalParams = property(get_AdditionalParams, None)
    Error = property(get_Error, None)
    ErrorDescription = property(get_ErrorDescription, None)
    ErrorUri = property(get_ErrorUri, None)
    State = property(get_State, None)
class AuthRequestParams(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams
    _classid_ = 'Microsoft.Security.Authentication.OAuth.AuthRequestParams'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams.CreateInstance(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams.CreateInstance2(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParamsFactory, responseType: WinRT_String, clientId: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
    @winrt_factorymethod
    def CreateInstance2(cls: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParamsFactory, responseType: WinRT_String, clientId: WinRT_String, redirectUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
    @winrt_mixinmethod
    def get_ResponseType(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ResponseType(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ClientId(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ClientId(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_RedirectUri(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_RedirectUri(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_State(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Scope(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Scope(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CodeChallenge(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CodeChallenge(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_CodeChallengeMethod(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> win32more.Microsoft.Security.Authentication.OAuth.CodeChallengeMethodKind: ...
    @winrt_mixinmethod
    def put_CodeChallengeMethod(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams, value: win32more.Microsoft.Security.Authentication.OAuth.CodeChallengeMethodKind) -> Void: ...
    @winrt_mixinmethod
    def get_AdditionalParams(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParams) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_classmethod
    def CreateForAuthorizationCodeRequest(cls: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParamsStatics, clientId: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
    @winrt_classmethod
    def CreateForAuthorizationCodeRequest2(cls: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestParamsStatics, clientId: WinRT_String, redirectUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
    AdditionalParams = property(get_AdditionalParams, None)
    ClientId = property(get_ClientId, put_ClientId)
    CodeChallenge = property(get_CodeChallenge, put_CodeChallenge)
    CodeChallengeMethod = property(get_CodeChallengeMethod, put_CodeChallengeMethod)
    RedirectUri = property(get_RedirectUri, put_RedirectUri)
    ResponseType = property(get_ResponseType, put_ResponseType)
    Scope = property(get_Scope, put_Scope)
    State = property(get_State, put_State)
class AuthRequestResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestResult
    _classid_ = 'Microsoft.Security.Authentication.OAuth.AuthRequestResult'
    @winrt_mixinmethod
    def get_ResponseUri(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestResult) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestResult) -> win32more.Microsoft.Security.Authentication.OAuth.AuthResponse: ...
    @winrt_mixinmethod
    def get_Failure(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthRequestResult) -> win32more.Microsoft.Security.Authentication.OAuth.AuthFailure: ...
    Failure = property(get_Failure, None)
    Response = property(get_Response, None)
    ResponseUri = property(get_ResponseUri, None)
class AuthResponse(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse
    _classid_ = 'Microsoft.Security.Authentication.OAuth.AuthResponse'
    @winrt_mixinmethod
    def get_State(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Code(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AccessToken(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TokenType(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExpiresIn(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Scope(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AdditionalParams(self: win32more.Microsoft.Security.Authentication.OAuth.IAuthResponse) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    AccessToken = property(get_AccessToken, None)
    AdditionalParams = property(get_AdditionalParams, None)
    Code = property(get_Code, None)
    ExpiresIn = property(get_ExpiresIn, None)
    Scope = property(get_Scope, None)
    State = property(get_State, None)
    TokenType = property(get_TokenType, None)
class ClientAuthentication(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthentication
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ClientAuthentication'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_overload
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication: ...
    @CreateInstance.register
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthenticationFactory, authorization: win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue) -> win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication: ...
    @winrt_mixinmethod
    def get_Authorization(self: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthentication) -> win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue: ...
    @winrt_mixinmethod
    def put_Authorization(self: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthentication, value: win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue) -> Void: ...
    @winrt_mixinmethod
    def get_ProxyAuthorization(self: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthentication) -> win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue: ...
    @winrt_mixinmethod
    def put_ProxyAuthorization(self: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthentication, value: win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue) -> Void: ...
    @winrt_mixinmethod
    def get_AdditionalHeaders(self: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthentication) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_classmethod
    def CreateForBasicAuthorization(cls: win32more.Microsoft.Security.Authentication.OAuth.IClientAuthenticationStatics, clientId: WinRT_String, clientSecret: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication: ...
    AdditionalHeaders = property(get_AdditionalHeaders, None)
    Authorization = property(get_Authorization, put_Authorization)
    ProxyAuthorization = property(get_ProxyAuthorization, put_ProxyAuthorization)
class CodeChallengeMethodKind(Enum, Int32):
    None_ = 0
    S256 = 1
    Plain = 2
class IAuthFailure(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IAuthFailure'
    _iid_ = Guid('{ec55ed5f-0497-53cb-976b-abd146350175}')
    @winrt_commethod(6)
    def get_Error(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ErrorDescription(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ErrorUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(9)
    def get_State(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_AdditionalParams(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    AdditionalParams = property(get_AdditionalParams, None)
    Error = property(get_Error, None)
    ErrorDescription = property(get_ErrorDescription, None)
    ErrorUri = property(get_ErrorUri, None)
    State = property(get_State, None)
class IAuthRequestParams(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IAuthRequestParams'
    _iid_ = Guid('{aac61e23-9155-551a-ac37-cdb2995f88d2}')
    @winrt_commethod(6)
    def get_ResponseType(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_ResponseType(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_ClientId(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_ClientId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_RedirectUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_RedirectUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(12)
    def get_State(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_State(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_Scope(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_Scope(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_CodeChallenge(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_CodeChallenge(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(18)
    def get_CodeChallengeMethod(self) -> win32more.Microsoft.Security.Authentication.OAuth.CodeChallengeMethodKind: ...
    @winrt_commethod(19)
    def put_CodeChallengeMethod(self, value: win32more.Microsoft.Security.Authentication.OAuth.CodeChallengeMethodKind) -> Void: ...
    @winrt_commethod(20)
    def get_AdditionalParams(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    AdditionalParams = property(get_AdditionalParams, None)
    ClientId = property(get_ClientId, put_ClientId)
    CodeChallenge = property(get_CodeChallenge, put_CodeChallenge)
    CodeChallengeMethod = property(get_CodeChallengeMethod, put_CodeChallengeMethod)
    RedirectUri = property(get_RedirectUri, put_RedirectUri)
    ResponseType = property(get_ResponseType, put_ResponseType)
    Scope = property(get_Scope, put_Scope)
    State = property(get_State, put_State)
class IAuthRequestParamsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IAuthRequestParamsFactory'
    _iid_ = Guid('{539bdca7-bde4-5a63-85d1-33403f6e3452}')
    @winrt_commethod(6)
    def CreateInstance(self, responseType: WinRT_String, clientId: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
    @winrt_commethod(7)
    def CreateInstance2(self, responseType: WinRT_String, clientId: WinRT_String, redirectUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
class IAuthRequestParamsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IAuthRequestParamsStatics'
    _iid_ = Guid('{0befd4f0-6864-5bf4-bd8e-2f3bf98906b5}')
    @winrt_commethod(6)
    def CreateForAuthorizationCodeRequest(self, clientId: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
    @winrt_commethod(7)
    def CreateForAuthorizationCodeRequest2(self, clientId: WinRT_String, redirectUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams: ...
class IAuthRequestResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IAuthRequestResult'
    _iid_ = Guid('{10f8b804-04cf-5651-bd52-7da9346debc1}')
    @winrt_commethod(6)
    def get_ResponseUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(7)
    def get_Response(self) -> win32more.Microsoft.Security.Authentication.OAuth.AuthResponse: ...
    @winrt_commethod(8)
    def get_Failure(self) -> win32more.Microsoft.Security.Authentication.OAuth.AuthFailure: ...
    Failure = property(get_Failure, None)
    Response = property(get_Response, None)
    ResponseUri = property(get_ResponseUri, None)
class IAuthResponse(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IAuthResponse'
    _iid_ = Guid('{5bc1fa62-fded-5769-9d40-ded1eea90d72}')
    @winrt_commethod(6)
    def get_State(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Code(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_AccessToken(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_TokenType(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_ExpiresIn(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_Scope(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_AdditionalParams(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    AccessToken = property(get_AccessToken, None)
    AdditionalParams = property(get_AdditionalParams, None)
    Code = property(get_Code, None)
    ExpiresIn = property(get_ExpiresIn, None)
    Scope = property(get_Scope, None)
    State = property(get_State, None)
    TokenType = property(get_TokenType, None)
class IClientAuthentication(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IClientAuthentication'
    _iid_ = Guid('{ef99342d-d597-5eff-878a-8de0cb597172}')
    @winrt_commethod(6)
    def get_Authorization(self) -> win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue: ...
    @winrt_commethod(7)
    def put_Authorization(self, value: win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue) -> Void: ...
    @winrt_commethod(8)
    def get_ProxyAuthorization(self) -> win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue: ...
    @winrt_commethod(9)
    def put_ProxyAuthorization(self, value: win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue) -> Void: ...
    @winrt_commethod(10)
    def get_AdditionalHeaders(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    AdditionalHeaders = property(get_AdditionalHeaders, None)
    Authorization = property(get_Authorization, put_Authorization)
    ProxyAuthorization = property(get_ProxyAuthorization, put_ProxyAuthorization)
class IClientAuthenticationFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IClientAuthenticationFactory'
    _iid_ = Guid('{0d50e9f5-c37f-57cc-b9ec-2b193b0f9cec}')
    @winrt_commethod(6)
    def CreateInstance(self, authorization: win32more.Windows.Web.Http.Headers.HttpCredentialsHeaderValue) -> win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication: ...
class IClientAuthenticationStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IClientAuthenticationStatics'
    _iid_ = Guid('{65613560-2b6f-52fd-a479-3a96624682ae}')
    @winrt_commethod(6)
    def CreateForBasicAuthorization(self, clientId: WinRT_String, clientSecret: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication: ...
class IOAuth2ManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.IOAuth2ManagerStatics'
    _iid_ = Guid('{ac9d0dd1-c07e-5302-8150-199c7d343f57}')
    @winrt_commethod(6)
    def RequestAuthWithParamsAsync(self, parentWindowId: win32more.Microsoft.UI.WindowId, authEndpoint: win32more.Windows.Foundation.Uri, params: win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Security.Authentication.OAuth.AuthRequestResult]: ...
    @winrt_commethod(7)
    def CompleteAuthRequest(self, responseUri: win32more.Windows.Foundation.Uri) -> Boolean: ...
    @winrt_commethod(8)
    def RequestTokenAsync(self, tokenEndpoint: win32more.Windows.Foundation.Uri, params: win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Security.Authentication.OAuth.TokenRequestResult]: ...
    @winrt_commethod(9)
    def RequestTokenAsync2(self, tokenEndpoint: win32more.Windows.Foundation.Uri, params: win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams, clientAuth: win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Security.Authentication.OAuth.TokenRequestResult]: ...
class ITokenFailure(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ITokenFailure'
    _iid_ = Guid('{60f8d417-ea6a-51d2-8ad7-f0e5177aef0a}')
    @winrt_commethod(6)
    def get_Kind(self) -> win32more.Microsoft.Security.Authentication.OAuth.TokenFailureKind: ...
    @winrt_commethod(7)
    def get_ErrorCode(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(8)
    def get_Error(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_ErrorDescription(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_ErrorUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def get_AdditionalParams(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Data.Json.IJsonValue]: ...
    AdditionalParams = property(get_AdditionalParams, None)
    Error = property(get_Error, None)
    ErrorCode = property(get_ErrorCode, None)
    ErrorDescription = property(get_ErrorDescription, None)
    ErrorUri = property(get_ErrorUri, None)
    Kind = property(get_Kind, None)
class ITokenRequestParams(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ITokenRequestParams'
    _iid_ = Guid('{49134dbc-aab5-5ba4-bcdf-950214d81182}')
    @winrt_commethod(6)
    def get_GrantType(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_GrantType(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Code(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Code(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_RedirectUri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(11)
    def put_RedirectUri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_commethod(12)
    def get_CodeVerifier(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_CodeVerifier(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_ClientId(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_ClientId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_Username(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_Username(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(18)
    def get_Password(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def put_Password(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(20)
    def get_Scope(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_Scope(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_RefreshToken(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def put_RefreshToken(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def get_AdditionalParams(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    AdditionalParams = property(get_AdditionalParams, None)
    ClientId = property(get_ClientId, put_ClientId)
    Code = property(get_Code, put_Code)
    CodeVerifier = property(get_CodeVerifier, put_CodeVerifier)
    GrantType = property(get_GrantType, put_GrantType)
    Password = property(get_Password, put_Password)
    RedirectUri = property(get_RedirectUri, put_RedirectUri)
    RefreshToken = property(get_RefreshToken, put_RefreshToken)
    Scope = property(get_Scope, put_Scope)
    Username = property(get_Username, put_Username)
class ITokenRequestParamsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ITokenRequestParamsFactory'
    _iid_ = Guid('{2bf39c30-2f30-5788-98d2-a8ba622be809}')
    @winrt_commethod(6)
    def CreateInstance(self, grantType: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
class ITokenRequestParamsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ITokenRequestParamsStatics'
    _iid_ = Guid('{68b7af65-4381-5593-8820-f74a605b9f3b}')
    @winrt_commethod(6)
    def CreateForAuthorizationCodeRequest(self, authResponse: win32more.Microsoft.Security.Authentication.OAuth.AuthResponse) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_commethod(7)
    def CreateForClientCredentials(self) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_commethod(8)
    def CreateForExtension(self, extensionUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_commethod(9)
    def CreateForRefreshToken(self, refreshToken: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
class ITokenRequestResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ITokenRequestResult'
    _iid_ = Guid('{35b31f77-f166-50df-a837-ec0460215166}')
    @winrt_commethod(6)
    def get_ResponseMessage(self) -> win32more.Windows.Web.Http.HttpResponseMessage: ...
    @winrt_commethod(7)
    def get_Response(self) -> win32more.Microsoft.Security.Authentication.OAuth.TokenResponse: ...
    @winrt_commethod(8)
    def get_Failure(self) -> win32more.Microsoft.Security.Authentication.OAuth.TokenFailure: ...
    Failure = property(get_Failure, None)
    Response = property(get_Response, None)
    ResponseMessage = property(get_ResponseMessage, None)
class ITokenResponse(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.ITokenResponse'
    _iid_ = Guid('{9d9d8cd3-04b2-5df6-bfd2-e8a6859745da}')
    @winrt_commethod(6)
    def get_AccessToken(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_TokenType(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_ExpiresIn(self) -> Double: ...
    @winrt_commethod(9)
    def get_RefreshToken(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Scope(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_AdditionalParams(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Data.Json.IJsonValue]: ...
    AccessToken = property(get_AccessToken, None)
    AdditionalParams = property(get_AdditionalParams, None)
    ExpiresIn = property(get_ExpiresIn, None)
    RefreshToken = property(get_RefreshToken, None)
    Scope = property(get_Scope, None)
    TokenType = property(get_TokenType, None)
class OAuth2Manager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Security.Authentication.OAuth.OAuth2Manager'
    @winrt_classmethod
    def RequestAuthWithParamsAsync(cls: win32more.Microsoft.Security.Authentication.OAuth.IOAuth2ManagerStatics, parentWindowId: win32more.Microsoft.UI.WindowId, authEndpoint: win32more.Windows.Foundation.Uri, params: win32more.Microsoft.Security.Authentication.OAuth.AuthRequestParams) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Security.Authentication.OAuth.AuthRequestResult]: ...
    @winrt_classmethod
    def CompleteAuthRequest(cls: win32more.Microsoft.Security.Authentication.OAuth.IOAuth2ManagerStatics, responseUri: win32more.Windows.Foundation.Uri) -> Boolean: ...
    @winrt_classmethod
    def RequestTokenAsync(cls: win32more.Microsoft.Security.Authentication.OAuth.IOAuth2ManagerStatics, tokenEndpoint: win32more.Windows.Foundation.Uri, params: win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Security.Authentication.OAuth.TokenRequestResult]: ...
    @winrt_classmethod
    def RequestTokenAsync2(cls: win32more.Microsoft.Security.Authentication.OAuth.IOAuth2ManagerStatics, tokenEndpoint: win32more.Windows.Foundation.Uri, params: win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams, clientAuth: win32more.Microsoft.Security.Authentication.OAuth.ClientAuthentication) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Security.Authentication.OAuth.TokenRequestResult]: ...
OAuthContract: UInt32 = 65536
class TokenFailure(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure
    _classid_ = 'Microsoft.Security.Authentication.OAuth.TokenFailure'
    @winrt_mixinmethod
    def get_Kind(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure) -> win32more.Microsoft.Security.Authentication.OAuth.TokenFailureKind: ...
    @winrt_mixinmethod
    def get_ErrorCode(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Error(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ErrorDescription(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ErrorUri(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_AdditionalParams(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenFailure) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Data.Json.IJsonValue]: ...
    AdditionalParams = property(get_AdditionalParams, None)
    Error = property(get_Error, None)
    ErrorCode = property(get_ErrorCode, None)
    ErrorDescription = property(get_ErrorDescription, None)
    ErrorUri = property(get_ErrorUri, None)
    Kind = property(get_Kind, None)
class TokenFailureKind(Enum, Int32):
    ErrorResponse = 0
    HttpFailure = 1
    InvalidResponse = 2
class TokenRequestParams(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams
    _classid_ = 'Microsoft.Security.Authentication.OAuth.TokenRequestParams'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParamsFactory, grantType: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_mixinmethod
    def get_GrantType(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_GrantType(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Code(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Code(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_RedirectUri(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_RedirectUri(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: win32more.Windows.Foundation.Uri) -> Void: ...
    @winrt_mixinmethod
    def get_CodeVerifier(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_CodeVerifier(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ClientId(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ClientId(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Username(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Username(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Password(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Password(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Scope(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Scope(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_RefreshToken(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_RefreshToken(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AdditionalParams(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParams) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]: ...
    @winrt_classmethod
    def CreateForAuthorizationCodeRequest(cls: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParamsStatics, authResponse: win32more.Microsoft.Security.Authentication.OAuth.AuthResponse) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_classmethod
    def CreateForClientCredentials(cls: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParamsStatics) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_classmethod
    def CreateForExtension(cls: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParamsStatics, extensionUri: win32more.Windows.Foundation.Uri) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    @winrt_classmethod
    def CreateForRefreshToken(cls: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestParamsStatics, refreshToken: WinRT_String) -> win32more.Microsoft.Security.Authentication.OAuth.TokenRequestParams: ...
    AdditionalParams = property(get_AdditionalParams, None)
    ClientId = property(get_ClientId, put_ClientId)
    Code = property(get_Code, put_Code)
    CodeVerifier = property(get_CodeVerifier, put_CodeVerifier)
    GrantType = property(get_GrantType, put_GrantType)
    Password = property(get_Password, put_Password)
    RedirectUri = property(get_RedirectUri, put_RedirectUri)
    RefreshToken = property(get_RefreshToken, put_RefreshToken)
    Scope = property(get_Scope, put_Scope)
    Username = property(get_Username, put_Username)
class TokenRequestResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestResult
    _classid_ = 'Microsoft.Security.Authentication.OAuth.TokenRequestResult'
    @winrt_mixinmethod
    def get_ResponseMessage(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestResult) -> win32more.Windows.Web.Http.HttpResponseMessage: ...
    @winrt_mixinmethod
    def get_Response(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestResult) -> win32more.Microsoft.Security.Authentication.OAuth.TokenResponse: ...
    @winrt_mixinmethod
    def get_Failure(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenRequestResult) -> win32more.Microsoft.Security.Authentication.OAuth.TokenFailure: ...
    Failure = property(get_Failure, None)
    Response = property(get_Response, None)
    ResponseMessage = property(get_ResponseMessage, None)
class TokenResponse(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse
    _classid_ = 'Microsoft.Security.Authentication.OAuth.TokenResponse'
    @winrt_mixinmethod
    def get_AccessToken(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TokenType(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ExpiresIn(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse) -> Double: ...
    @winrt_mixinmethod
    def get_RefreshToken(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Scope(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_AdditionalParams(self: win32more.Microsoft.Security.Authentication.OAuth.ITokenResponse) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Data.Json.IJsonValue]: ...
    AccessToken = property(get_AccessToken, None)
    AdditionalParams = property(get_AdditionalParams, None)
    ExpiresIn = property(get_ExpiresIn, None)
    RefreshToken = property(get_RefreshToken, None)
    Scope = property(get_Scope, None)
    TokenType = property(get_TokenType, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Xaml.Resources
class _CustomXamlResourceLoader_Meta_(ComPtr.__class__):
    pass
class CustomXamlResourceLoader(ComPtr, metaclass=_CustomXamlResourceLoader_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoader
    _classid_ = 'Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader: ...
    @winrt_mixinmethod
    def GetResource(self: win32more.Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderOverrides, resourceId: WinRT_String, objectType: WinRT_String, propertyName: WinRT_String, propertyType: WinRT_String) -> IInspectable: ...
    @winrt_classmethod
    def get_Current(cls: win32more.Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderStatics) -> win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader: ...
    @winrt_classmethod
    def put_Current(cls: win32more.Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderStatics, value: win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader) -> Void: ...
    _CustomXamlResourceLoader_Meta_.Current = property(get_Current, put_Current)
class ICustomXamlResourceLoader(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoader'
    _iid_ = Guid('{2832c2e5-2ace-5993-a173-3c9c3b992b2e}')
class ICustomXamlResourceLoaderFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderFactory'
    _iid_ = Guid('{174d49a6-e1e2-5f7b-a618-a8a953d1b5a0}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader: ...
class ICustomXamlResourceLoaderOverrides(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderOverrides'
    _iid_ = Guid('{84bb504c-6730-586a-bd04-9198264b2dc7}')
    @winrt_commethod(6)
    def GetResource(self, resourceId: WinRT_String, objectType: WinRT_String, propertyName: WinRT_String, propertyType: WinRT_String) -> IInspectable: ...
class ICustomXamlResourceLoaderStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Resources.ICustomXamlResourceLoaderStatics'
    _iid_ = Guid('{e08a5a92-b1a2-539a-9d4a-7994e4468cd7}')
    @winrt_commethod(6)
    def get_Current(self) -> win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader: ...
    @winrt_commethod(7)
    def put_Current(self, value: win32more.Microsoft.UI.Xaml.Resources.CustomXamlResourceLoader) -> Void: ...
    Current = property(get_Current, put_Current)


make_ready(__name__)
